@@ -15,7 +15,7 @@ except ImportError:
 
 import struct
 
-from maxminddb.compat import byte_from_int, int_from_byte, compat_ip_address
+from maxminddb.compat import byte_from_int, compat_ip_address
 from maxminddb.const import MODE_AUTO, MODE_MMAP, MODE_FILE, MODE_MEMORY
 from maxminddb.decoder import Decoder
 from maxminddb.errors import InvalidDatabaseError
@@ -23,7 +23,6 @@ from maxminddb.file import FileBuffer
 
 
 class Reader(object):
-
     """
     Instances of this class provide a reader for the MaxMind DB format. IP
     addresses can be looked up using the ``get`` method.
@@ -60,13 +59,14 @@ class Reader(object):
                 self._buffer = db_file.read()
                 self._buffer_size = len(self._buffer)
         else:
-            raise ValueError('Unsupported open mode ({0}). Only MODE_AUTO, '
-                             ' MODE_FILE, and MODE_MEMORY are support by the pure Python '
-                             'Reader'.format(mode))
+            raise ValueError(
+                'Unsupported open mode ({0}). Only MODE_AUTO, '
+                ' MODE_FILE, and MODE_MEMORY are support by the pure Python '
+                'Reader'.format(mode))
 
-        metadata_start = self._buffer.rfind(self._METADATA_START_MARKER,
-                                            max(0, self._buffer_size
-                                                - 128 * 1024))
+        metadata_start = self._buffer.rfind(
+            self._METADATA_START_MARKER, max(0,
+                                             self._buffer_size - 128 * 1024))
 
         if metadata_start == -1:
             self.close()
@@ -77,11 +77,10 @@ class Reader(object):
         metadata_start += len(self._METADATA_START_MARKER)
         metadata_decoder = Decoder(self._buffer, metadata_start)
         (metadata, _) = metadata_decoder.decode(metadata_start)
-        self._metadata = Metadata(
-            **metadata)  # pylint: disable=bad-option-value
+        self._metadata = Metadata(**metadata)  # pylint: disable=bad-option-value
 
-        self._decoder = Decoder(self._buffer, self._metadata.search_tree_size
-                                + self._DATA_SECTION_SEPARATOR_SIZE)
+        self._decoder = Decoder(self._buffer, self._metadata.search_tree_size +
+                                self._DATA_SECTION_SEPARATOR_SIZE)
 
     def metadata(self):
         """Return the metadata associated with the MaxMind DB file"""
@@ -98,15 +97,15 @@ class Reader(object):
         address = compat_ip_address(ip_address)
 
         if address.version == 6 and self._metadata.ip_version == 4:
-            raise ValueError('Error looking up {0}. You attempted to look up '
-                             'an IPv6 address in an IPv4-only database.'.format(
-                                 ip_address))
+            raise ValueError(
+                'Error looking up {0}. You attempted to look up '
+                'an IPv6 address in an IPv4-only database.'.format(ip_address))
         pointer = self._find_address_in_tree(address)
 
         return self._resolve_data_pointer(pointer) if pointer else None
 
     def _find_address_in_tree(self, ip_address):
-        packed = ip_address.packed
+        packed = bytearray(ip_address.packed)
 
         bit_count = len(packed) * 8
         node = self._start_node(bit_count)
@@ -114,7 +113,7 @@ class Reader(object):
         for i in range(bit_count):
             if node >= self._metadata.node_count:
                 break
-            bit = 1 & (int_from_byte(packed[i >> 3]) >> 7 - (i % 8))
+            bit = 1 & (packed[i >> 3] >> 7 - (i % 8))
             node = self._read_node(node, bit)
         if node == self._metadata.node_count:
             # Record is empty
@@ -149,21 +148,21 @@ class Reader(object):
             offset = base_offset + index * 3
             node_bytes = b'\x00' + self._buffer[offset:offset + 3]
         elif record_size == 28:
-            (middle,) = struct.unpack(
+            (middle, ) = struct.unpack(
                 b'!B', self._buffer[base_offset + 3:base_offset + 4])
             if index:
                 middle &= 0x0F
             else:
                 middle = (0xF0 & middle) >> 4
             offset = base_offset + index * 4
-            node_bytes = byte_from_int(
-                middle) + self._buffer[offset:offset + 3]
+            node_bytes = byte_from_int(middle) + self._buffer[offset:offset +
+                                                              3]
         elif record_size == 32:
             offset = base_offset + index * 4
             node_bytes = self._buffer[offset:offset + 4]
         else:
-            raise InvalidDatabaseError(
-                'Unknown record size: {0}'.format(record_size))
+            raise InvalidDatabaseError('Unknown record size: {0}'.format(
+                record_size))
         return struct.unpack(b'!I', node_bytes)[0]
 
     def _resolve_data_pointer(self, pointer):
@@ -185,7 +184,6 @@ class Reader(object):
 
 
 class Metadata(object):
-
     """Metadata for the MaxMind DB reader"""
 
     # pylint: disable=too-many-instance-attributes
