@@ -33,13 +33,12 @@ if sys.version_info[0] == 2:
 
 
 class BaseTestReader(object):
-
     def test_reader(self):
         for record_size in [24, 28, 32]:
             for ip_version in [4, 6]:
-                file_name = ('tests/data/test-data/MaxMind-DB-test-ipv' +
-                             str(ip_version) + '-' + str(record_size) +
-                             '.mmdb')
+                file_name = (
+                    'tests/data/test-data/MaxMind-DB-test-ipv' +
+                    str(ip_version) + '-' + str(record_size) + '.mmdb')
                 reader = open_database(file_name, self.mode)
 
                 self._check_metadata(reader, ip_version, record_size)
@@ -61,25 +60,20 @@ class BaseTestReader(object):
         self.assertEqual(record['double'], 42.123456)
         self.assertAlmostEqual(record['float'], 1.1)
         self.assertEqual(record['int32'], -268435456)
-        self.assertEqual(
-            {
-                'mapX': {
-                    'arrayX': [7, 8, 9],
-                    'utf8_stringX': 'hello'
-                },
+        self.assertEqual({
+            'mapX': {
+                'arrayX': [7, 8, 9],
+                'utf8_stringX': 'hello'
             },
-            record['map']
-        )
+        }, record['map'])
 
         self.assertEqual(record['uint16'], 100)
         self.assertEqual(record['uint32'], 268435456)
         self.assertEqual(record['uint64'], 1152921504606846976)
         self.assertEqual(record['utf8_string'], 'unicode! ☯ - ♫')
 
-        self.assertEqual(
-            1329227995784915872903807060280344576,
-            record['uint128']
-        )
+        self.assertEqual(1329227995784915872903807060280344576,
+                         record['uint128'])
         reader.close()
 
     def test_no_ipv4_search_tree(self):
@@ -94,8 +88,7 @@ class BaseTestReader(object):
     def test_ipv6_address_in_ipv4_database(self):
         reader = open_database(
             'tests/data/test-data/MaxMind-DB-test-ipv4-24.mmdb', self.mode)
-        with self.assertRaisesRegex(ValueError,
-                                    'Error looking up 2001::. '
+        with self.assertRaisesRegex(ValueError, 'Error looking up 2001::. '
                                     'You attempted to look up an IPv6 address '
                                     'in an IPv4-only database'):
             reader.get('2001::')
@@ -108,8 +101,7 @@ class BaseTestReader(object):
         with self.assertRaisesRegex(InvalidDatabaseError,
                                     "The MaxMind DB file's data "
                                     "section contains bad data \(unknown data "
-                                    "type or corrupt data\)"
-                                    ):
+                                    "type or corrupt data\)"):
             reader.get('2001:220::')
         reader.close()
 
@@ -118,13 +110,11 @@ class BaseTestReader(object):
             'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
         self.assertRaisesRegex(ValueError,
                                "'not_ip' does not appear to be an IPv4 or "
-                               "IPv6 address",
-                               reader.get, ('not_ip'))
+                               "IPv6 address", reader.get, ('not_ip'))
         reader.close()
 
     def test_missing_database(self):
-        self.assertRaisesRegex(FileNotFoundError,
-                               "No such file or directory",
+        self.assertRaisesRegex(FileNotFoundError, "No such file or directory",
                                open_database, 'file-does-not-exist.mmdb',
                                self.mode)
 
@@ -136,84 +126,72 @@ class BaseTestReader(object):
 
     def test_too_many_constructor_args(self):
         cls = self.readerClass[0]
-        self.assertRaises(
-            TypeError, cls, 'README.md', self.mode, 1)
+        self.assertRaises(TypeError, cls, 'README.md', self.mode, 1)
 
     def test_bad_constructor_mode(self):
         cls = self.readerClass[0]
         self.assertRaisesRegex(
-            ValueError, 'Unsupported open mode \(100\)', cls, 'README.md',
+            ValueError,
+            'Unsupported open mode \(100\)',
+            cls,
+            'README.md',
             mode=100)
 
     def test_no_constructor_args(self):
         cls = self.readerClass[0]
         self.assertRaisesRegex(
-            TypeError, ' 1 required positional argument|\(pos 1\) not found|takes at least 2 arguments',
+            TypeError,
+            ' 1 required positional argument|\(pos 1\) not found|takes at least 2 arguments',
             cls)
 
     def test_too_many_get_args(self):
         reader = open_database(
-            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode
-        )
+            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
         self.assertRaises(TypeError, reader.get, ('1.1.1.1', 'blah'))
         reader.close()
 
     def test_no_get_args(self):
         reader = open_database(
-            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb',
-            self.mode
-        )
+            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
         self.assertRaises(TypeError, reader.get)
         reader.close()
 
     def test_metadata_args(self):
         reader = open_database(
-            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb',
-            self.mode
-        )
+            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
         self.assertRaises(TypeError, reader.metadata, ('blah'))
         reader.close()
 
     def test_metadata_unknown_attribute(self):
         reader = open_database(
-            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb',
-            self.mode
-        )
+            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
         metadata = reader.metadata()
-        with self.assertRaisesRegex(AttributeError,
-                                    "'Metadata' object has no "
+        with self.assertRaisesRegex(AttributeError, "'Metadata' object has no "
                                     "attribute 'blah'"):
             metadata.blah
         reader.close()
 
     def test_close(self):
         reader = open_database(
-            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb',
-            self.mode
-        )
+            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
         reader.close()
 
     def test_double_close(self):
         reader = open_database(
-            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb',
-            self.mode
-        )
+            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
         reader.close()
-        self.assertIsNone(
-            reader.close(), 'Double close does not throw an exception')
+        self.assertIsNone(reader.close(),
+                          'Double close does not throw an exception')
 
     def test_closed_get(self):
         if self.mode == MODE_MEMORY:
             return
         reader = open_database(
-            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb',
-            self.mode
-        )
+            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
         reader.close()
         self.assertRaisesRegex(ValueError,
                                'Attempt to read from a closed MaxMind DB.'
-                               '|closed',
-                               reader.get, ('1.1.1.1'))
+                               '|closed', reader.get, ('1.1.1.1'))
 
     # XXX - Figure out whether we want to have the same behavior on both the
     #       extension and the pure Python reader. If we do, the pure Python
@@ -221,9 +199,7 @@ class BaseTestReader(object):
     #       to keep the metadata in memory.
     def test_closed_metadata(self):
         reader = open_database(
-            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb',
-            self.mode
-        )
+            'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
         reader.close()
 
         # The primary purpose of this is to ensure the extension doesn't
@@ -234,8 +210,8 @@ class BaseTestReader(object):
             self.assertEqual('Attempt to read from a closed MaxMind DB.',
                              str(ex), 'extension throws exception')
         else:
-            self.assertIsNotNone(
-                metadata, 'pure Python implementation returns value')
+            self.assertIsNotNone(metadata,
+                                 'pure Python implementation returns value')
 
     def test_multiprocessing(self):
         self._check_concurrency(Process)
@@ -244,16 +220,15 @@ class BaseTestReader(object):
         self._check_concurrency(threading.Thread)
 
     if sys.version_info[0] == 2:
+
         def test_byte_ip_on_python2(self):
             reader = open_database(
                 'tests/data/test-data/MaxMind-DB-test-decoder.mmdb', self.mode)
             record = reader.get(b'::1.1.1.0')
 
     def _check_concurrency(self, worker_class):
-        reader = open_database(
-            'tests/data/test-data/GeoIP2-Domain-Test.mmdb',
-            self.mode
-        )
+        reader = open_database('tests/data/test-data/GeoIP2-Domain-Test.mmdb',
+                               self.mode)
 
         def lookup(pipe):
             try:
@@ -268,7 +243,7 @@ class BaseTestReader(object):
                 pipe.close()
 
         pipes = [Pipe() for _ in range(32)]
-        procs = [worker_class(target=lookup, args=(c,)) for (p, c) in pipes]
+        procs = [worker_class(target=lookup, args=(c, )) for (p, c) in pipes]
         for proc in procs:
             proc.start()
         for proc in procs:
@@ -283,19 +258,16 @@ class BaseTestReader(object):
     def _check_metadata(self, reader, ip_version, record_size):
         metadata = reader.metadata()
 
-        self.assertEqual(
-            2,
-            metadata.binary_format_major_version,
-            'major version'
-        )
+        self.assertEqual(2, metadata.binary_format_major_version,
+                         'major version')
         self.assertEqual(metadata.binary_format_minor_version, 0)
         self.assertGreater(metadata.build_epoch, 1373571901)
         self.assertEqual(metadata.database_type, 'Test')
 
-        self.assertEqual(
-            {'en': 'Test Database', 'zh': 'Test Database Chinese'},
-            metadata.description
-        )
+        self.assertEqual({
+            'en': 'Test Database',
+            'zh': 'Test Database Chinese'
+        }, metadata.description)
         self.assertEqual(metadata.ip_version, ip_version)
         self.assertEqual(metadata.languages, ['en', 'zh'])
         self.assertGreater(metadata.node_count, 36)
@@ -305,12 +277,12 @@ class BaseTestReader(object):
     def _check_ip_v4(self, reader, file_name):
         for i in range(6):
             address = '1.1.1.' + str(pow(2, i))
-            self.assertEqual(
-                {'ip': address},
-                reader.get(address),
-                'found expected data record for '
-                + address + ' in ' + file_name
-            )
+            self.assertEqual({
+                'ip': address
+            },
+                             reader.get(address),
+                             'found expected data record for ' + address +
+                             ' in ' + file_name)
 
         pairs = {
             '1.1.1.3': '1.1.1.2',
@@ -324,27 +296,26 @@ class BaseTestReader(object):
         for key_address, value_address in pairs.items():
             data = {'ip': value_address}
 
-            self.assertEqual(
-                data,
-                reader.get(key_address),
-                'found expected data record for ' + key_address + ' in '
-                + file_name
-            )
+            self.assertEqual(data,
+                             reader.get(key_address),
+                             'found expected data record for ' + key_address +
+                             ' in ' + file_name)
 
         for ip in ['1.1.1.33', '255.254.253.123']:
             self.assertIsNone(reader.get(ip))
 
     def _check_ip_v6(self, reader, file_name):
-        subnets = ['::1:ffff:ffff', '::2:0:0',
-                   '::2:0:40', '::2:0:50', '::2:0:58']
+        subnets = [
+            '::1:ffff:ffff', '::2:0:0', '::2:0:40', '::2:0:50', '::2:0:58'
+        ]
 
         for address in subnets:
-            self.assertEqual(
-                {'ip': address},
-                reader.get(address),
-                'found expected data record for ' + address + ' in '
-                + file_name
-            )
+            self.assertEqual({
+                'ip': address
+            },
+                             reader.get(address),
+                             'found expected data record for ' + address +
+                             ' in ' + file_name)
 
         pairs = {
             '::2:0:1': '::2:0:0',
@@ -358,12 +329,12 @@ class BaseTestReader(object):
         }
 
         for key_address, value_address in pairs.items():
-            self.assertEqual(
-                {'ip':  value_address},
-                reader.get(key_address),
-                'found expected data record for ' + key_address + ' in '
-                + file_name
-            )
+            self.assertEqual({
+                'ip': value_address
+            },
+                             reader.get(key_address),
+                             'found expected data record for ' + key_address +
+                             ' in ' + file_name)
 
         for ip in ['1.1.1.33', '255.254.253.123', '89fa::']:
             self.assertIsNone(reader.get(ip))
@@ -373,8 +344,8 @@ def has_maxminddb_extension():
     return maxminddb.extension and hasattr(maxminddb.extension, 'Reader')
 
 
-@unittest.skipIf(not has_maxminddb_extension()
-                 and not os.environ.get('MM_FORCE_EXT_TESTS'),
+@unittest.skipIf(not has_maxminddb_extension() and
+                 not os.environ.get('MM_FORCE_EXT_TESTS'),
                  'No C extension module found. Skipping tests')
 class TestExtensionReader(BaseTestReader, unittest.TestCase):
     mode = MODE_MMAP_EXT
@@ -408,7 +379,6 @@ class TestMemoryReader(BaseTestReader, unittest.TestCase):
 
 
 class TestOldReader(unittest.TestCase):
-
     def test_old_reader(self):
         reader = maxminddb.Reader(
             'tests/data/test-data/MaxMind-DB-test-decoder.mmdb')
